<?php
/**
 * OpenMage
 *
 * This source file is subject to the Open Software License (OSL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available at https://opensource.org/license/osl-3-0-php
 *
 * @category    Tests
 * @package     Tests_Functional
 * @copyright  Copyright (c) 2006-2020 Magento, Inc. (https://www.magento.com)
 * @license    https://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 */

namespace Mage\Adminhtml\Test\Block\System\Currency;

use Mage\Adminhtml\Test\Block\PageActions;
use Mage\Core\Test\Block\Messages;

/**
 * Grid page actions on the SystemCurrencyIndex page.
 */
class GridPageActions extends PageActions
{
    /**
     * Import button locator.
     *
     * @var string
     */
    protected $importButton = '.scalable.add';

    /**
     * Message block css selector.
     *
     * @var string
     */
    protected $message = '#messages';

    /**
     * "Save Currency Rates" button locator.
     *
     * @var string
     */
    protected $saveCurrentRate = '.scalable.save';

    /**
     * Click Import button.
     *
     * @throws \Exception
     * @return void
     */
    public function clickImportButton()
    {
        $this->_rootElement->find($this->importButton)->click();

        //Wait message
        $browser = $this->browser;
        $selector = $this->message;
        $browser->waitUntil(
            function () use ($browser, $selector) {
                $message = $browser->find($selector);
                return $message->isVisible() ? true : null;
            }
        );
        if ($this->getMessageBlock()->isVisibleMessage('warning')) {
            throw new \Exception($this->getMessageBlock()->getWarningMessages());
        }
    }

    /**
     * Get message block.
     *
     * @return Messages
     */
    protected function getMessageBlock()
    {
        return $this->blockFactory->create(
            'Mage\Core\Test\Block\Messages',
            ['element' => $this->_rootElement->find($this->message)]
        );
    }

    /**
     * Save Currency Rates.
     *
     * @return void
     */
    public function saveCurrentRate()
    {
        $this->_rootElement->find($this->saveCurrentRate)->click();
    }
}
